@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from enum import Enum
 
-from agentbox.envd.filesystem_agentbox.filesystem_pb2 import AgentBoxFileType,AgentBoxEventType
+from agentbox.envd.filesystem.filesystem_pb2 import FileType,EventType
 
 
-class AgentBoxFilesystemEventType(Enum):
+class FilesystemEventType(Enum):
     """
     Enum representing the type of filesystem event.
     """
@@ -31,21 +31,21 @@ class AgentBoxFilesystemEventType(Enum):
     """
 
 
-def map_event_type(event: AgentBoxFileType):
-    if event == AgentBoxEventType.EVENT_TYPE_CHMOD:
-        return AgentBoxFilesystemEventType.CHMOD
-    elif event == AgentBoxEventType.EVENT_TYPE_CREATE:
-        return AgentBoxFilesystemEventType.CREATE
-    elif event == AgentBoxEventType.EVENT_TYPE_REMOVE:
-        return AgentBoxFilesystemEventType.REMOVE
-    elif event == AgentBoxEventType.EVENT_TYPE_RENAME:
-        return AgentBoxFilesystemEventType.RENAME
-    elif event == AgentBoxEventType.EVENT_TYPE_WRITE:
-        return AgentBoxFilesystemEventType.WRITE
+def map_event_type(event: FileType):
+    if event == EventType.EVENT_TYPE_CHMOD:
+        return FilesystemEventType.CHMOD
+    elif event == EventType.EVENT_TYPE_CREATE:
+        return FilesystemEventType.CREATE
+    elif event == EventType.EVENT_TYPE_REMOVE:
+        return FilesystemEventType.REMOVE
+    elif event == EventType.EVENT_TYPE_RENAME:
+        return FilesystemEventType.RENAME
+    elif event == EventType.EVENT_TYPE_WRITE:
+        return FilesystemEventType.WRITE
 
 
 @dataclass
-class AgentBoxFilesystemEvent:
+class FilesystemEvent:
     """
     Contains information about the filesystem event - the name of the file and the type of the event.
     """
@@ -54,7 +54,7 @@ class AgentBoxFilesystemEvent:
     """
     Relative path to the filesystem object.
     """
-    type: AgentBoxFilesystemEventType
+    type: FilesystemEventType
     """
     Filesystem operation event type.
     """
