@@ -7,7 +7,7 @@ from packaging.version import Version
 from agentbox.sandbox.sandbox_api import SandboxInfo, SandboxApiBase, SandboxQuery, ListedSandbox
 from agentbox.exceptions import TemplateException
 from agentbox.api import AsyncApiClient, SandboxCreateResponse
-from agentbox.api.client.models import NewSandbox, PostSandboxesSandboxIDTimeoutBody, SandboxADB, SandboxSSH, InstanceAuthInfo
+from agentbox.api.client.models import NewSandbox, PostSandboxesSandboxIDTimeoutBody, SandboxADB, SandboxADBPublicInfo, SandboxSSH, InstanceAuthInfo, ResumedSandbox
 from agentbox.api.client.api.sandboxes import (
     get_sandboxes_sandbox_id,
     post_sandboxes_sandbox_id_timeout,
@@ -18,6 +18,9 @@ from agentbox.api.client.api.sandboxes import (
     get_sandboxes_sandbox_id_ssh,
     get_sandboxes_sandbox_id_instance_no,
     get_sandboxes_sandbox_id_instance_auth_info,
+    get_sandboxes_sandbox_id_adb_public_info,
+    post_sandboxes_sandbox_id_pause,
+    post_sandboxes_sandbox_id_resume,
 )
 from agentbox.connection_config import ConnectionConfig, ProxyTypes
 from agentbox.api import handle_api_exception
@@ -313,6 +316,55 @@ class SandboxApi(SandboxApiBase):
                 raise Exception("Body of the request is None")
 
             return res.parsed
+        
+    @classmethod
+    async def _get_adb_public_info(
+        cls,
+        sandbox_id: str,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+        headers: Optional[Dict[str, str]] = None,
+        proxy: Optional[ProxyTypes] = None,
+    ) -> SandboxADBPublicInfo:
+        """
+        Get the sandbox ADB public information.
+        :param sandbox_id: Sandbox ID
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
+        :param request_timeout: Timeout for the request in **seconds**
+        :param headers: Additional headers to send with the request
+        :param proxy: Proxy to use for the request
+
+        :return: Sandbox ADB info
+        """
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+            headers=headers,
+            proxy=proxy,
+        )
+
+        async with AsyncApiClient(
+            config,
+            limits=cls._limits,
+        ) as api_client:
+            res = await get_sandboxes_sandbox_id_adb_public_info.asyncio_detailed(
+                sandbox_id,
+                client=api_client,
+            )
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            if res.parsed is None:
+                raise Exception("Body of the request is None")
+
+            return res.parsed
 
     @classmethod
     async def _get_ssh(
@@ -507,3 +559,71 @@ class SandboxApi(SandboxApiBase):
                 envd_version=res.parsed.envd_version,
                 envd_access_token=res.parsed.envd_access_token,
             )
+
+    @classmethod
+    async def _cls_resume(
+        cls,
+        sandbox_id: str,
+        timeout: int,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+    ) -> bool:
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+        )
+
+        async with AsyncApiClient(config,limits=SandboxApiBase._limits) as api_client:
+            res = await post_sandboxes_sandbox_id_resume.asyncio_detailed(
+                sandbox_id,
+                client=api_client,
+                body=ResumedSandbox(timeout=timeout),
+            )
+
+            if res.status_code == 404:
+                raise Exception(f"Paused sandbox {sandbox_id} not found")
+
+            if res.status_code == 409:
+                return False
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            return True
+
+    @classmethod
+    async def _cls_pause(
+        cls,
+        sandbox_id: str,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+    ) -> bool:
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+        )
+
+        async with AsyncApiClient(config,limits=SandboxApiBase._limits) as api_client:
+            res = await post_sandboxes_sandbox_id_pause.asyncio_detailed(
+                sandbox_id,
+                client=api_client,
+            )
+
+            if res.status_code == 404:
+                raise Exception(f"Sandbox {sandbox_id} not found")
+
+            if res.status_code == 409:
+                return False
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            return True
\ No newline at end of file
